@@ -1153,6 +1153,10 @@
         <source>Info on current fractal</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Copy position URL</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Message</name>
@@ -1418,5 +1422,13 @@
         <source>XaoS must restart to change the language.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Clipboard set to %s.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mouse:[%1.12f,%1.12f]</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
