@@ -1141,6 +1141,10 @@
         <source>User Forum</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Copy position URL</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Message</name>
@@ -1403,5 +1407,13 @@
         <source>Welcome to XaoS version %s</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Clipboard set to %s.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mouse:[%1.12f,%1.12f]</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
