@@ -4,7 +4,8 @@
 #include "config.h"
 struct image;
 
-const char *writepng(xio_constpath filename, const struct image *image);
+const char *writepng(xio_constpath filename, const struct image *image, xio_file xpf_data);
+const char* readpng(xio_constpath filename);
 void XaoS_srandom(unsigned int x);
 long int XaoS_random(void);
 char *mystrdup(const char *);
