@@ -34,7 +34,7 @@ typedef char *(*tokenfunc)(struct uih_context *c);
 #define DIALOG_PALSLIDER 10
 #define DIALOG_PALPICKER 11
 #define DIALOG_IFILES 12
-#define DIALOG_ILIST 13
+#define DIALOG_LIST 13
 
 #define DIALOGIFILE(question, filename)                                        \
     {                                                                          \
@@ -80,6 +80,10 @@ typedef char *(*tokenfunc)(struct uih_context *c);
     {                                                                          \
         question, DIALOG_IFILES, 0, filenames                                  \
     }
+#define DIALOGLIST(question, default)                                          \
+    {                                                                          \
+        question, DIALOG_LIST, 0, default                                      \
+    }
 
 #define DIALOGIFILE_I(_question, _filename)                                    \
     menudialogs_i18n[no_menudialogs_i18n].question = _question;                \
@@ -166,9 +170,9 @@ typedef char *(*tokenfunc)(struct uih_context *c);
     menudialogs_i18n[no_menudialogs_i18n].defstr = _filenames;                 \
     ++no_menudialogs_i18n;
 
-#define DIALOGILIST_I(_question, _default)                                     \
+#define DIALOGLIST_I(_question, _default)                                      \
     menudialogs_i18n[no_menudialogs_i18n].question = _question;                \
-    menudialogs_i18n[no_menudialogs_i18n].type = DIALOG_ILIST;                 \
+    menudialogs_i18n[no_menudialogs_i18n].type = DIALOG_LIST;                  \
     menudialogs_i18n[no_menudialogs_i18n].defint = 0;                          \
     menudialogs_i18n[no_menudialogs_i18n].defstr = _default;                   \
     ++no_menudialogs_i18n;
