@@ -326,7 +326,7 @@ static void ui_about(struct uih_context *uih)
             "<br>"
             "Fast interactive real-time fractal zoomer/morpher<br><br>"
             "Original Authors: Jan Hubička and Thomas Marsh<br>"
-            "Copyright © 1996-2023 XaoS Contributors<br>"
+            "Copyright © 1996-2024 <a href=\"https://github.com/xaos-project/XaoS/blob/master/CREDITS.md\">XaoS Contributors</a><br>"
             "<br>"
             "This program is free software; you can redistribute it and/or modify "
             "it under the terms of the GNU General Public License as published by "
@@ -398,7 +398,7 @@ static int ui_fullscreenselected(struct uih_context *uih)
 #endif
 
 /* WARNING: Increase this number in case there are new menu items added. */
-#define MAX_MENUITEMS_I18N 34
+#define MAX_MENUITEMS_I18N 36
 /* These variables must be global: */
 static menuitem *menuitems;
 static menuitem menuitems_i18n[MAX_MENUITEMS_I18N];
@@ -419,10 +419,10 @@ char languageSetting[6] = "";
 bool languageSysDefault = true;
 // please keep the languages in the same order
 const char *languages1[] = {
-    "__", "cs", "en", "fr", "de", "he", "hi", "hu", "is", "it", "pt", "ro", "ru", "rs", "es", "sv", "vi"
+    "__", "cs", "en", "fr", "de", "he", "hi", "hu", "is", "it", "pt", "ro", "ru", "rs", "es", "sv", "tr", "vi"
 };
 const char *languages2[] = {
-    "_____", "cs_CZ", "en_US", "fr_FR", "de_DE", "he_IL", "hi_HI", "hu_HU", "is_IS", "it_IT", "pt_PT", "ro_RO", "ru_RU", "rs_RS", "es_ES", "sv_SV", "vi_VN"
+    "_____", "cs_CZ", "en_US", "fr_FR", "de_DE", "he_IL", "hi_HI", "hu_HU", "is_IS", "it_IT", "pt_PT", "ro_RO", "ru_RU", "rs_RS", "es_ES", "sv_SV", "tr_TR", "vi_VN"
 };
 
 const char *lang1(int i) {
@@ -524,6 +524,8 @@ static void ui_registermenus_i18n(void)
                 UIH_LANG_ES, ui_languageselected);
     MENUINTRB_I("setlang", NULL, "Swedish", "sv", UI, uih_setlanguage,
                 UIH_LANG_SV, ui_languageselected);
+    MENUINTRB_I("setlang", NULL, "Turkish", "tr", UI, uih_setlanguage,
+                UIH_LANG_TR, ui_languageselected);
     MENUINTRB_I("setlang", NULL, "Vietnamese", "vi", UI, uih_setlanguage,
                 UIH_LANG_VI, ui_languageselected);
 
